@@ -1,5 +1,5 @@
 package Curio::Role;
-our $VERSION = '0.05';
+our $VERSION = '0.06';
 
 =encoding utf8
 
@@ -139,6 +139,20 @@ sub uninject {
     return $class->factory->uninject( @_ );
 }
 
+=head2 injection
+
+    my $curio_object = MyApp::Service::Cache->injection();
+    my $curio_object = MyApp::Service::Cache->injection( $key );
+
+This proxies to L<Curio::Factory/injection>.
+
+=cut
+
+sub injection {
+    my $class = shift;
+    return $class->factory->injection( @_ );
+}
+
 =head2 initialize
 
 Sets up your class's L<Curio::Factory> object and is automatically
@@ -166,18 +180,18 @@ Returns the class's L<Curio::Factory> object.
 # Curio::Factory::_install_factory_method()
 sub factory { undef }
 
-=head2 keys
+=head2 declared_keys
 
-    my $keys = MyApp::Service::Cache->keys();
+    my $keys = MyApp::Service::Cache->declared_keys();
     foreach my $key (@$keys) { ... }
 
-This proxies to L<Curio::Factory/keys>.
+This proxies to L<Curio::Factory/declared_keys>.
 
 =cut
 
-sub keys {
+sub declared_keys {
     my $class = shift;
-    return $class->factory->keys( @_ );
+    return $class->factory->declared_keys( @_ );
 }
 
 1;
